@@ -10,6 +10,7 @@ use Toader::findToaderRoot;
 use Toader::Directory;
 use Sys::Hostname;
 use Toader::Config;
+use Toader::VCS;
 
 =head1 NAME
 
@@ -17,11 +18,11 @@ Toader - A CMS meant to be integrated with a versioning system.
 
 =head1 VERSION
 
-Version 0.4.0
+Version 1.1.1
 
 =cut
 
-our $VERSION = '0.4.0';
+our $VERSION = '1.1.1';
 
 =head1 SYNOPSIS
 
@@ -48,9 +49,9 @@ This is required and needs to be a Toader directory.
 
 This is the output directory to use when rendering.
 
-    my $foo=Toader->new(\%args);
-    if ( $foo->error ){
-        warn('Error:'.$foo->error.': '.$foo->errorString);
+    my $toader=Toader->new(\%args);
+    if ( $toader->error ){
+        warn('Error:'.$toader->error.':'.$toader->errorFlag.': '.$toader->errorString);
     }
 
 =cut
@@ -67,6 +68,19 @@ sub new{
 			  isatd=>Toader::isaToaderDir->new,
 			  perror=>undef,
 			  outputdir=>undef,
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noDirSpecified',
+					  2=>'isaToaderDirError',
+					  3=>'notAtoaderDir',
+					  4=>'outputIsAtoaderDir',
+					  5=>'DirectoryInitError',
+					  6=>'ConfigInitError',
+					  7=>'PathHerlerInitError',
+					  8=>'VCSinitError',
+					  9=>'VCSusableError',
+				  },
+			  },
 			  };
 	bless $self;
 
@@ -125,6 +139,27 @@ sub new{
 		$self->{outputdir}=$args{outputdir};
 	}
 
+	# intialize the VCS integration
+	$self->{vcs}=Toader::VCS->new($self);
+	if ( $self->{vcs}->error ){
+		$self->{perror}=1;
+		$self->{error}=8;
+		$self->{errorString}='Failed to initiate VCS. error="'.
+			$self->{vcs}->error.'" errorString="'.$self->{vcs}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+	# VCS usable
+	$self->{VCSusable}=$self->{vcs}->usable;
+	if ( $self->{vcs}->error ){
+		$self->{perror}=1;
+		$self->{error}=9;
+		$self->{errorString}='Toader::VCS->usable errored. error="'.
+			$self->{vcs}->error.'" errorString="'.$self->{vcs}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+
 	# initialize the config
 	$self->{config}=Toader::Config->new( $self );
 	if ( $self->{config}->error ){
@@ -135,8 +170,8 @@ sub new{
 		$self->warn;
 		return $self;
 	}
-	
 
+	# initialize the path helper
 	$self->{ph}=Toader::pathHelper->new( $self->{dir} );
 	if ( $self->{ph}->error ){
 		$self->{perror}=1;
@@ -158,7 +193,10 @@ config.
 There is no need to do any error checking as long as
 Toader new suceeded with out issue.
 
-    my $config=$foo->getConfig;
+    my $config=$toader->getConfig;
+    if ( $toader->error ){
+        warn('Error:'.$toader->error.':'.$toader->errorFlag.': '.$toader->errorString);
+    }
 
 =cut
 
@@ -178,7 +216,10 @@ sub getConfig{
 This returns the L<Toader::Config> object that was created
 when this module was created.
 
-    my $configObj=$foo->getConfigObj;
+    my $configObj=$toader->getConfigObj;
+    if ( $toader->error ){
+        warn('Error:'.$toader->error.':'.$toader->errorFlag.': '.$toader->errorString);
+    }
 
 =cut
 
@@ -198,9 +239,9 @@ sub getConfigObj{
 This returns a L<Toader::Directory> object with the directory
 set to the Toader root.
 
-    my $dirobj=$foo->getDirObj;
-    if ( $foo->error ){
-        warn('Error:'.$foo->error.': '.$foo->errorString);
+    my $dirobj=$toader->getDirObj;
+    if ( $toader->error ){
+        warn('Error:'.$toader->error.':'.$toader->errorFlag.': '.$toader->errorString);
     }
 
 =cut
@@ -213,7 +254,7 @@ sub getDirObj{
 		return undef;
 	}
 
-	my $dirobj=Toader::Directory->new;
+	my $dirobj=Toader::Directory->new( $self );
 
 	$dirobj->dirSet( $self->{dir} );
 	if ( $dirobj->error ){
@@ -236,7 +277,7 @@ If none is specified, undef is returned.
 There is no reason for check for errors if new
 succeeded with out error.
 
-    my $outputdir=$foo->getOutputDir;
+    my $outputdir=$toader->getOutputDir;
     if( defined( $outputdir ) ){
         print "outputdir='".$outputdir."'\n";
     }else{
@@ -263,7 +304,10 @@ This returns a L<Toader::pathHelper> object for this Toader object.
 If the Toader object initialized with out issue, then there is no reason
 to check for an error.
 
-    my $pathHelper=$foo->getPathHelper;
+    my $pathHelper=$toader->getPathHelper;
+    if ( $toader->error ){
+        warn('Error:'.$toader->error.':'.$toader->errorFlag.': '.$toader->errorString);
+    }
 
 =cut
 
@@ -284,7 +328,10 @@ This returns the root directory for what Toader is using.
 
 If the returned value is not defined, one has not been set yet.
 
-    my $rootdir=$foo->getRootDir;
+    my $rootdir=$toader->getRootDir;
+    if ( $foo->error ){
+        warn('Error:'.$foo->error.':'.$toader->errorFlag.': '.$foo->errorString);
+    }
 
 =cut
 
@@ -306,7 +353,7 @@ This sets the output directory.
 
     $foo->setOutputDir( $dir );
     if ( $foo->error ){
-        warn('Error:'.$foo->error.': '.$foo->errorString);
+        warn('Error:'.$foo->error.':'.$toader->errorFlag.': '.$foo->errorString);
     }
 
 =cut
@@ -349,36 +396,66 @@ sub setOutputDir{
 	return 1;
 }
 
+=head2 getVCS
+
+This returns to the L<Toader::VCS> object.
+
+    my $vcs=$toader->getVCS;
+    if ( $toader->error ){
+        warn('Error:'.$toader->error.':'.$toader->errorFlag.': '.$toader->errorString);
+    }
+
+=cut
+
+sub getVCS{
+	my $self=$_[0];
+	
+	#blank any previous errors
+	if(!$self->errorblank){
+		return undef;
+	}
+
+	return $self->{vcs};
+}
+
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, noDirSpecified
 
 No directory specified.
 
-=head2 2
+=head2 2, isaToaderDirError
 
 Toader::isaToaderDir->isaToaderDir errored.
 
-=head2 3
+=head2 3, notAtoaderDir
 
 The specified directory is not a Toader directory.
 
-=head2 4
+=head2 4, outputIsAtoaderDir
 
 The specified output directory is a Toader directory.
 
-=head2 5
+=head2 5, DirectoryInitError
 
 Could initialize the L<Toader::Directory> object.
 
-=head2 6
+=head2 6, ConfigInitError
 
 Failed to initialize L<Toader::Config>.
 
-=head2 7
+=head2 7, PathHerlerInitError
 
 Failed to initiate the path helper.
 
+=head2 8, VCSinitError
+
+Failed to initiate VCS integration.
+
+=head2 9, VCSusableError
+
+Toader::VCS->usable errored.
+
 =head1 AUTHOR
 
 Zane C. Bowers-Hadley, C<< <vvelox at vvelox.net> >>
@@ -428,7 +505,7 @@ L<http://search.cpan.org/dist/Toader/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Zane C. Bowers-Hadley
+Copyright 2013 Zane C. Bowers-Hadley
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
