@@ -12,11 +12,11 @@ Toader::Directory - This the index file for a Toader directory.
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.1.0';
 
 =head1 SYNOPSIS
 
@@ -27,9 +27,11 @@ please see 'Documentation/Directory.pod'.
 
 =head2 new
 
-If any of the new methods error, the error is permanent.
+This initializes the object.
 
-    my $foo = Toader::Directory->new;
+One argument is required and it is a L<Toader> object.
+
+    my $foo = Toader::Directory->new($toader);
     if ($foo->error){
         warn('Error:'.$foo->error.': '.$foo->errorString);
     }
@@ -37,14 +39,75 @@ If any of the new methods error, the error is permanent.
 =cut
 
 sub new{
+	my $toader=$_[1];
+
 	my $self={
 			  error=>undef,
 			  errorString=>'',
 			  perror=>undef,
 			  dir=>undef,
+			  errorExtra=>{
+				  flags=>{
+					  1=>'openIndexFailed',
+					  2=>'noAtoaderDir',
+					  3=>'noTitleSpecified',
+					  4=>'noDirSet',
+					  5=>'noLongerAtoaderDir',
+					  6=>'indexOpenForWritingFailed',
+					  7=>'openDirFailed',
+					  8=>'noSummarySpecified',
+					  9=>'notAtoaderObj',
+					  10=>'getVCSerrored',
+					  11=>'VCSusableErrored',
+					  12=>'underVCSerrored',
+					  13=>'VCSaddErrored',
+					  14=>'noToaderObj',
+				  },
+			  },
+			  VCSusable=>0,
 			  };
 	bless $self;
 
+	#if we have a Toader object, reel it in
+	if ( ! defined( $toader ) ){
+		$self->{perror}=1;
+		$self->{error}=14;
+		$self->{errorString}='No Toader object specified';
+		$self->warn;
+		return $self;
+
+	}
+	if ( ref( $toader ) ne "Toader" ){
+		$self->{perror}=1;
+		$self->{error}=9;
+		$self->{errorString}='The object specified is a "'.ref($toader).'"';
+		$self->warn;
+		return $self;
+	}
+	$self->{toader}=$toader;
+
+	#gets the Toader::VCS object
+	$self->{vcs}=$self->{toader}->getVCS;
+	if ( $toader->error ){
+		$self->{perror}=1;
+		$self->{error}=10;
+		$self->{errorString}='Toader->getVCS errored. error="'.
+			$self->{toader}->error.'" errorString="'.$self->{toader}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+	
+	#checks if VCS is usable
+	$self->{VCSusable}=$self->{vcs}->usable;
+	if ( $self->{vcs}->error ){
+		$self->{perror}=1;
+		$self->{error}=11;
+		$self->{errorString}='Toader::VCS->usable errored. error="'.
+			$self->{toader}->error.'" errorString="'.$self->{toader}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+
 	return $self;
 }
 
@@ -738,7 +801,30 @@ sub write{
 	}
 	print $fh $pageString;
 	close($fh);
-	
+
+	#if it is under VCS, we have nothing to do
+	my $underVCS=$self->{vcs}->underVCS($file);
+	if ( $self->{vcs}->error ){
+		$self->{error}=12;
+		$self->{errorString}='Toader::VCS->underVCS errored. error="'.
+			$self->{vcs}->error.'" errorString="'.$self->{vcs}->errorString.'"';
+		$self->warn;
+		return undef;
+	}
+	if ( $underVCS ){
+		return 1;
+	}
+
+	#add it as if we reach here it is not under VCS and VCS is being used
+	$self->{vcs}->add( $file );
+	if ( $self->{vcs}->error ){
+		$self->{error}=13;
+		$self->{errorString}='Toader::VCS->add errored. error="'.
+			$self->{vcs}->error.'" errorString="'.$self->{vcs}->errorString.'"';
+		$self->warn;
+		return undef;
+	}
+
 	return 1;
 }
 
@@ -837,38 +923,62 @@ sub toDir{
 
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, openIndexFailed
 
 Unable to open the index file for the specified directory.
 
-=head2 2
+=head2 2, notAtoaderDir
 
 The specified directory is not a L<Toader> directory.
 
-=head2 3
+=head2 3, noTitleSpecified
 
 No title specified.
 
-=head2 4
+=head2 4, noDirSet
 
 No directory has been specified yet.
 
-=head2 5
+=head2 5, noLongerAtoaderDir
 
 The directory is no longer a L<Toader> directory.
 
-=head2 6
+=head2 6, indexOpenForWritingFailed
 
 Failed to open the file for writing.
 
-=head2 7
+=head2 7, openDirFailed
 
 Failed to open the directory.
 
-=head2 8
+=head2 8, noSummarySpecified
 
 No summary specified.
 
+=head2 9, notAtoaderObj
+
+The specified objected is not a L<Toader> object.
+
+=head2 10, getVCSerrored
+
+L<Toader>->getVCS errored.
+
+=head2 11, VCSusableErrored
+
+L<Toader::VCS>->usable errored.
+
+=head2 12, underVCSerrored
+
+L<Toader::VCS>->underVCS errored.
+
+=head2 13, VCSaddErrored
+
+L<Toader::VCS>->add errored.
+
+=head2 14, noToaderObj
+
+No L<Toader> object specified.
+
 =head1 AUTHOR
 
 Zane C. Bowers-Hadley, C<< <vvelox at vvelox.net> >>
@@ -914,7 +1024,7 @@ L<http://search.cpan.org/dist/Toader/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011 Zane C. Bowers-Hadley
+Copyright 2013 Zane C. Bowers-Hadley
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
