@@ -12,11 +12,11 @@ Toader::Gallery - Handle image galleries.
 
 =head1 VERSION
 
-Version 0.0.0
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.0';
+our $VERSION = '0.1.0';
 
 =head1 METHODS
 
@@ -24,7 +24,10 @@ our $VERSION = '0.0.0';
 
 This initiates the object.
 
-    my $foo = Toader::AutoDoc->new;
+There is one  argument is required and this is a
+L<Toader> object.
+
+    my $foo = Toader::AutoDoc->new($toader);
     if ( $foo->error ){
         warn('error:'.$foo->error.': '.$foo->errorString);
     }
@@ -32,17 +35,140 @@ This initiates the object.
 =cut
 
 sub new{
+	my $toader=$_[1];
+
 	my $self={
 			  error=>undef,
 			  errorString=>'',
 			  perror=>undef,
 			  dir=>undef,
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noDirSpecified',
+					  2=>'notAtoaderDir',
+					  3=>'readConfigFailed',
+					  4=>'noConfig',
+					  5=>'nonNumericResolution',
+					  6=>'noSrcPath',
+					  7=>'noSrcURL',
+					  8=>'noOutputPath',
+					  9=>'noOutputURL',
+					  10=>'dirAlreadyInit',
+					  11=>'pathHelperErrored',
+					  12=>'notAtoaderObj',
+					  13=>'getVCSerrored',
+					  14=>'VCSusableErrored',
+					  15=>'underVCSerrored',
+					  16=>'VCSaddErrored',
+					  17=>'VCSdeleteErrored',
+					  18=>'noToaderObj',
+				  },
+			  },
+			  VCSusable=>0,
 			  };
 	bless $self;
 
+	#if we have a Toader object, reel it in
+	if ( ! defined( $toader ) ){
+		$self->{perror}=1;
+		$self->{error}=18;
+		$self->{errorString}='No Toader object specified';
+		$self->warn;
+		return $self;
+	}
+	if ( ref( $toader ) ne "Toader" ){
+		$self->{perror}=1;
+		$self->{error}=12;
+		$self->{errorString}='The object specified is a "'.ref($toader).'"';
+		$self->warn;
+		return $self;
+	}
+	$self->{toader}=$toader;
+
+	#gets the Toader::VCS object
+	$self->{vcs}=$self->{toader}->getVCS;
+	if ( $toader->error ){
+		$self->{perror}=1;
+		$self->{error}=13;
+		$self->{errorString}='Toader->getVCS errored. error="'.
+			$self->{toader}->error.'" errorString="'.$self->{toader}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+	
+	#checks if VCS is usable
+	$self->{VCSusable}=$self->{vcs}->usable;
+	if ( $self->{vcs}->error ){
+		$self->{perror}=1;
+		$self->{error}=14;
+		$self->{errorString}='Toader::VCS->usable errored. error="'.
+			$self->{toader}->error.'" errorString="'.$self->{toader}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+
 	return $self;
 }
 
+=head2 delConfig
+
+This removes a gallery config for a directory.
+
+=cut
+
+sub delConfig{
+	my $self=$_[0];
+
+	if (!$self->errorblank){
+		return undef;
+	}
+
+    if ( ! defined( $self->{config} ) ){
+        $self->{error}=4;
+        $self->{errorString}='No config for the current directory';
+        $self->warn;
+        return undef;
+    }
+
+	my $file=$self->{dir}.'/.toader/gallery.ini';
+	if ( ! unlink( $file ) ){
+		$self->{error}=11;
+		$self->{errorString}='Failed to write the config out to "'.$file.'"';
+		$self->warn;
+		return undef;
+	}
+	
+	#if VCS is not usable, stop here
+	if ( ! $self->{VCSusable} ){
+		return 1;
+	}
+
+	#if it is under VCS, we have nothing to do
+	my $underVCS=$self->{vcs}->underVCS($file);
+	if ( $self->{vcs}->error ){
+		$self->{error}=15;
+		$self->{errorString}='Toader::VCS->underVCS errored. error="'.
+			$self->{vcs}->error.'" errorString="'.$self->{vcs}->errorString.'"';
+		$self->warn;
+		return undef;
+	}
+	if ( $underVCS ){
+		return 1;
+	}
+
+	#delete it as if we reach here it is not under VCS and VCS is being used
+	$self->{vcs}->delete( $file );
+	if ( $self->{vcs}->error ){
+		$self->{error}=17;
+		$self->{errorString}='Toader::VCS->delete errored. error="'.
+			$self->{vcs}->error.'" errorString="'.$self->{vcs}->errorString.'"';
+		$self->warn;
+		return undef;
+	}
+
+	return 1;
+}
+
 =head2 dirGet
 
 This gets L<Toader> directory this entry is associated with.
@@ -944,13 +1070,42 @@ sub writeConfig{
         return undef;
     }
 
-	if ( ! $self->{config}->write( $self->{dir}.'/.toader/gallery.ini' ) ){
+	my $file=$self->{dir}.'/.toader/gallery.ini';
+	if ( ! $self->{config}->write( $file ) ){
 		$self->{error}=11;
-		$self->{errorString}='Failed to write the config out to "'.$self->{dir}.'/.toader/gallery.ini"';
+		$self->{errorString}='Failed to write the config out to "'.$file.'"';
 		$self->warn;
 		return undef;
 	}
-	
+
+	#if VCS is not usable, stop here
+	if ( ! $self->{VCSusable} ){
+		return 1;
+	}
+
+	#if it is under VCS, we have nothing to do
+	my $underVCS=$self->{vcs}->underVCS($file);
+	if ( $self->{vcs}->error ){
+		$self->{error}=15;
+		$self->{errorString}='Toader::VCS->underVCS errored. error="'.
+			$self->{vcs}->error.'" errorString="'.$self->{vcs}->errorString.'"';
+		$self->warn;
+		return undef;
+	}
+	if ( $underVCS ){
+		return 1;
+	}
+
+	#add it as if we reach here it is not under VCS and VCS is being used
+	$self->{vcs}->add( $file );
+	if ( $self->{vcs}->error ){
+		$self->{error}=16;
+		$self->{errorString}='Toader::VCS->add errored. error="'.
+			$self->{vcs}->error.'" errorString="'.$self->{vcs}->errorString.'"';
+		$self->warn;
+		return undef;
+	}
+
 	return 1;
 }
 
@@ -1066,50 +1221,78 @@ sub toDir{
 
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, noDirSpecified
 
 No directory specified.
 
-=head2 2
+=head2 2, notAtoaderDir
 
 The directory is not a Toader directory.
 
-=head2 3
+=head2 3, readConfigFailed
 
 Failed to read the gallery config.
 
-=head2 4
+=head2 4, noConfig
 
 No config for this directory.
 
-=head2 5
+=head2 5, nonNumericResolution
 
 The specified resolution is non-numeric.
 
-=head2 6
+=head2 6, noSrcPath
 
 No source path specified.
 
-=head2 7
+=head2 7, noSrcURL
 
 No source URL specified.
 
-=head2 8
+=head2 8, noOutputPath
 
 No output path specified.
 
-=head2 9
+=head2 9, noOutputURL
 
 No output URL specified.
 
-=head2 10
+=head2 10, dirAlreadyInit
 
 The directory has already been initialized.
 
-=head2 11
+=head2 11, pathHelperErrored
 
 Failed to initialize Toader::pathHelper.
 
+=head2 12, notAtoaderObj
+
+Not a Toader object.
+
+=head2 13, getVCSerrored
+
+L<Toader>->getVCS errored.
+
+=head2 14, VCSusableErrored
+
+L<Toader::VCS>->usable errored.
+
+=head2 15, underVCSerrored
+
+L<Toader::VCS>->underVCS errored.
+
+=head2 16, VCSaddErrored
+
+L<Toader::VCS>->add errored.
+
+=head2 17, VCSdeleteErrored
+
+L<Toader::VCS>->delete errored.
+
+=head2 18, noToaderObj
+
+Nothing passed for a L<Toader> object.
+
 =head1 AUTHOR
 
 Zane C. Bowers-Hadley, C<< <vvelox at vvelox.net> >>
