@@ -16,11 +16,11 @@ Toader::Render::Entry - This renders a Toader::Entry object.
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.1.1
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.1.1';
 
 =head1 SYNOPSIS
 
@@ -67,6 +67,24 @@ sub new{
 			  errorString=>'',
 			  perror=>undef,
 			  toDir=>'../../',
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noObj',
+					  2=>'noToaderObj',
+					  3=>'objPerror',
+					  4=>'toaderObjPerror',
+					  5=>'noDirSet',
+					  6=>'cleanupInitErrored',
+					  7=>'cleanupErrored',
+					  8=>'backendInitErrored',
+					  9=>'pathhelperInitErrored',
+					  11=>'noOutputDirSet',
+					  12=>'outputDirDoesNotExist',
+					  13=>'outputEntryDirCreationFailed',
+					  14=>'outputFileDirCreationFailed',
+					  15=>'generalInitErrored',
+				  },
+			  },
 			  };
 	bless $self;
 
@@ -136,9 +154,13 @@ sub new{
 		$self->warn;
 		return $self;
 	}
+	$self->{dir}=$self->{obj}->dirGet;
 
 	#initialize this here for simplicity
-	$self->{t}=Toader::Templates->new({ dir=>$self->{obj}->dirGet });
+	$self->{t}=Toader::Templates->new({
+		dir=>$self->{obj}->dirGet,
+		toader=>$args{toader},
+									  });
 
 	#initialize the general object here for simplicity
 	$self->{g}=Toader::Render::General->new(
@@ -158,16 +180,6 @@ sub new{
 		return $self;
 	}
 
-	#make sure the renderable object has a directory set
-	$self->{dir}=$self->{obj}->dirGet;
-	if ( ! defined( $self->{dir} ) ){
-		$self->{perror}=1;
-		$self->{error}=10;
-		$self->{errorString}='The renderable object does not have a directory specified';
-		$self->warn;
-		return $self;
-	}
-
 	#initialize the Toader::pathHelper
 	$self->{ph}=Toader::pathHelper->new( $self->{dir} );
 	if ( $self->{ph}->error ){
@@ -668,65 +680,61 @@ sub render{
 
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, noObj
 
 No L<Toader::Entry> object specified.
 
-=head2 2
+=head2 2, noToaderObj
 
 No L<Toader> object specified.
 
-=head2 3
+=head2 3, objPerror
 
 The L<Toader::Entry> object has a permanent error set.
 
-=head2 4
+=head2 4, toaderObjPerror
 
 The L<Toader> object has a permanent error set.
 
-=head2 5
+=head2 5, noDirSet
 
 The L<Toader::Entry> object does not have a directory set
 
-=head2 6
+=head2 6, cleanupInitErrored
 
 Failed to initialize the cleanup module.
 
-=head2 7
+=head2 7, cleanupErrored
 
 Failed to cleanup.
 
-=head2 8
+=head2 8, backendInitErrored
 
 Failed to initialize the backend.
 
-=head2 9
+=head2 9, pathhelperInitErrored
 
 Failed to initialize the path helper.
 
-=head2 10
+=head2 11, noOutputDirSet
 
-The object does not have a directory set.
+The L<Toader> object does not have a output directory set.
 
-=head2 11
-
-The Toader object does not have a output directory set.
-
-=head2 12
+=head2 12, outputDirDoesNotExist
 
 The output directory does not exist.
 
-=head2 13
+=head2 13, outputEntryDirCreationFailed
 
 The output entry directory could not be created.
 
-=head2 14
+=head2 14, outputFileDirCreationFailed
 
 The output file directory could not be created.
 
-=head2 15
+=head2 15, generalInitErrored
 
-Failed to initialize the L<Toader::General::Object>.
+Failed to initialize the L<Toader::Render::General> object.
 
 =head1 AUTHOR
 
