@@ -11,11 +11,11 @@ Toader::findToaderDirs - Finds all Toader directories under a specified Toader d
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.1.0';
 
 =head1 SYNOPSIS
 
@@ -45,6 +45,16 @@ sub new{
 			  error=>undef,
 			  errorString=>'',
 			  isatd=>Toader::isaToaderDir->new,
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noDirSpecified',
+					  2=>'notAdir',
+					  3=>'notAtoaderDir',
+					  4=>'isaToaderDirErrored',
+					  5=>'rootIsAtoaderDir',
+					  6=>'dirOpenFailed',
+				  },
+			  },
 			  };
 	bless $self;
 
@@ -229,29 +239,29 @@ sub findToaderSubDirs{
 
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, noDirSpecified
 
 No directory specified.
 
-=head2 2
+=head2 2, notAdir
 
 Not a directory.
 
-=head2 3
+=head2 3, notAtoaderDir
 
 Not a L<Toader> directory.
 
-=head2 4
+=head2 4, isaToaderDirErrored
 
-Toader::isaToaderDir->isaToaderDir errored.
+L<Toader::isaToaderDir>->isaToaderDir errored.
 
-=head2 5
+=head2 5, rootIsAtoaderDir
 
 "/" is the directory and it appears to be a L<Toader> directory.
 
 This is a major WTF and should not be even if '/.toader' exists.
 
-=head2 6
+=head2 6, dirOpenFailed
 
 Could not open one of the directories.
 
@@ -300,7 +310,7 @@ L<http://search.cpan.org/dist/Toader/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011 Zane C. Bowers-Hadley.
+Copyright 2013 Zane C. Bowers-Hadley.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
@@ -311,4 +321,4 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
-1; # End of Toader
+1; # End of Toader::findToaderDirs
